#
# spec file for package python-PyInstaller
#
# Copyright (c) 2020 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%{?!python_module:%define python_module() python-%{**} python3-%{**}}
%define skip_python2 1
%bcond_without python2
%bcond_without  test
Name:           python-PyInstaller
Version:        3.6
Release:        bp154.1.38
Summary:        Bundle a Python application and all its dependencies into a single package
License:        GPL-2.0-only
URL:            https://www.pyinstaller.org
Source:         https://files.pythonhosted.org/packages/source/P/PyInstaller/PyInstaller-%{version}.tar.gz
BuildRequires:  %{python_module devel}
BuildRequires:  %{python_module setuptools}
BuildRequires:  fdupes
BuildRequires:  pkgconfig
BuildRequires:  python-rpm-macros
BuildRequires:  pkgconfig(zlib)
Requires:       python-devel
Requires:       python-macholib >= 1.8
Requires:       python-pefile >= 2017.8.1
Requires:       python-setuptools
Requires(post): update-alternatives
Requires(postun): update-alternatives
Recommends:     upx
%if %{with test}
BuildRequires:  %{python_module Babel}
BuildRequires:  %{python_module Django}
BuildRequires:  %{python_module QtAwesome}
BuildRequires:  %{python_module Sphinx}
BuildRequires:  %{python_module cryptography}
BuildRequires:  %{python_module docutils}
BuildRequires:  %{python_module macholib >= 1.8}
BuildRequires:  %{python_module matplotlib}
BuildRequires:  %{python_module opengl}
BuildRequires:  %{python_module pefile >= 2017.8.1}
BuildRequires:  %{python_module psutil}
BuildRequires:  %{python_module pycountry}
BuildRequires:  %{python_module pytest-xdist}
BuildRequires:  %{python_module pytest}
BuildRequires:  %{python_module qt5}
BuildRequires:  %{python_module setuptools}
BuildRequires:  upx
%if %{with python2}
BuildRequires:  python-dis3
%endif
%endif
%ifpython2
Requires:       python-dis3
%endif
%python_subpackages

%description
PyInstaller bundles a Python application and all its dependencies into a single
package. The user can run the packaged app without installing a Python
interpreter or any modules.

%prep
%setup -q -n PyInstaller-%{version}
chmod a-x PyInstaller/utils/hooks/__init__.py

# Force build of bootloader
rm -r PyInstaller/bootloader

%build
# -Wno-stringop-overflow only needed on ppc64
export CFLAGS="%{optflags} -Wno-stringop-truncation -Wno-unused-variable -Wno-unused-function -Wno-unused-but-set-variable -Wno-stringop-overflow"
%python_build

%install
%python_install
%{python_expand  # Relocate to sitearch
if [ "%{$python_sitearch}" != "%{$python_sitelib}" ]; then
  mkdir -p %{buildroot}%{$python_sitearch}
  mv %{buildroot}%{$python_sitelib}/* %{buildroot}%{$python_sitearch}
fi
%fdupes %{buildroot}%{$python_sitearch}
}

%python_clone -a %{buildroot}%{_bindir}/pyinstaller
%python_clone -a %{buildroot}%{_bindir}/pyi-archive_viewer
%python_clone -a %{buildroot}%{_bindir}/pyi-bindepend
%python_clone -a %{buildroot}%{_bindir}/pyi-grab_version
%python_clone -a %{buildroot}%{_bindir}/pyi-makespec
%python_clone -a %{buildroot}%{_bindir}/pyi-set_version

%if %{with test}
%check
export LANG=en_US.UTF-8
# test_get_co_using_ctypes, test_get_co_using_ctypes_from_extension, test_replace_paths_in_code broken with python 3.8 on PyInstall 3.6
%pytest_arch -n auto tests/unit -k 'not (test_find_module or test_egg and not test_nspkg1 or test_get_co_using_ctypes or test_get_co_using_ctypes_from_extension or test_replace_paths_in_code)'
%endif

%post
%{python_install_alternative pyinstaller pyi-archive_viewer pyi-bindepend pyi-grab_version pyi-makespec pyi-set_version}

%postun
%python_uninstall_alternative pyinstaller

%files %{python_files}
%doc README.rst doc/CHANGES.rst
%license COPYING.txt
%python_alternative %{_bindir}/pyinstaller
%python_alternative %{_bindir}/pyi-archive_viewer
%python_alternative %{_bindir}/pyi-bindepend
%python_alternative %{_bindir}/pyi-grab_version
%python_alternative %{_bindir}/pyi-makespec
%python_alternative %{_bindir}/pyi-set_version
%{python_sitearch}/*

%changelog
* Fri Mar 12 2021 Yuchen Lin <mlin+factory@suse.de>
- Do not build the python2 package since QtAwesome is python3 only
* Wed Mar 18 2020 Tomáš Chvátal <tchvatal@suse.com>
- Disable functional tests as it takes ages and basic checks
  are okay with unittests
* Tue Mar 10 2020 Tomáš Chvátal <tchvatal@suse.com>
- Use xdist for test execution as otherwise it takes ages
* Fri Jan 17 2020 Alberto Planas Dominguez <aplanas@suse.com>
- Requires python-devel, as `pyinstaller` cannot be used without it
* Fri Jan 17 2020 Alberto Planas Dominguez <aplanas@suse.com>
- Temporary disabled of tests test_egg* and test_nspkg1*
* Thu Jan 16 2020 Alberto Planas Dominguez <aplanas@suse.com>
- Update to version 3.6
  * See changelog at https://github.com/pyinstaller/pyinstaller/blob/v3.6/doc/CHANGES.rst
- Add %%bcond_with python2
* Mon Sep 23 2019 Tomáš Chvátal <tchvatal@suse.com>
- Format with spec-cleaner, fix license
* Fri Sep 20 2019 John Vandenberg <jayvdb@gmail.com>
- Delete upstream bootloaders from the source distribution, forcing
  re-compilation of bootloader for all platforms, removing 'noarch'
- Lightly update spec, year and https
- Update to v3.5
  * See changelog at https://github.com/pyinstaller/pyinstaller/blob/v3.5/doc/CHANGES.rst
* Wed Oct 18 2017 toddrme2178@gmail.com
- Implement single-spec version
- Update to version 3.3
  * See changelog at https://github.com/pyinstaller/pyinstaller/blob/v3.3/doc/CHANGES.rst
* Mon Jan 23 2017 termim@gmail.com
- use update-alternatives
- update to 3.2.1
  * New, updated and fixed hooks: botocore (#2094), gi (#2347), jira (#2222),
    PyQt5.QtWebEngineWidgets (#2269), skimage (#2195, 2225), sphinx (#2323,)
    xsge_gui (#2251).
  * Don't fail if working directory already exists (#1994)
  * Avoid encoding errors in main script (#1976)
  * Fix hasher digest bytes not str (#2229, #2230)
  * (Windows) Fix additional dependency on the msvcrt10.dll (#1974)
  * (Windows) Correctly decode a bytes object produced by pefile (#1981)
  * (Windows) Package ``pefile`` with pyinstaller.  This partially
    undoes some changes in 3.2 in which the packaged pefiles were
    removed to use the pypi version instead.  The pypi version was
    considerably slower in some applications, and still has a couple
    of small issues on PY3. (#1920)
  * (OS X) PyQt5 packaging issues on MacOS (#1874)
  * (OS X) Replace run-time search path keyword (#1965)
  * (OS X) (Re-) add argv emulation for OSX, 64-bit (#2219)
  * (OS X) use decode("utf-8") to convert bytes in getImports_macholib() (#1973)
  * (Bootloader) fix segfaults (#2176)
  * (setup.py) pass option --no-lsb on GNU/Linux only (#1975)
  * Updates and fixes in documentation, manuals, et al. (#1986, 2002, #2153,
    [#2227], #2231)
- update to version 3.2:
  * Even the “main” script is now byte-compiled (#1847, #1856)
  * The manual is on readthedocs.io now (#1578)
  * On installation try to compile the bootloader if there is none for
    the current plattform (#1377)
  * (Unix) Use objcopy to create a valid ELF file (#1812, #1831)
  * (Linux): Compile with _FORTIFY_SOURCE (#1820)
  * New, updated and fixed hooks: CherryPy (#1860), Cryptography
    (#1425, #1861), enchant (1562), gi.repository.GdkPixbuf (#1843),
    gst (#1963), Lib2to3 (#1768), PyQt4, PyQt5, PySide (#1783, #1897,
    [#1887]), SciPy (#1908, #1909), sphinx (#1911, #1912), sqlalchemy
    (#1951), traitlets wx.lib.pubsub (#1837, #1838),
  * For windowed mode add isatty() for our dummy NullWriter (#1883)
  * Suppress “Failed to execute script” in case of SystemExit (#1869)
  * Do not apply Upx compressor for bootloader files (#1863)
  * Fix absolute path for lib used via ctypes (#1934)
  * (OSX) Fix binary cache on NFS (#1573, #1849)
  * (Windows) Fix message in grab_version (#1923)
  * (Windows) Fix wrong icon paramter in Windows example (#1764)
  * (Windows) Fix win32 unicode handling (#1878)
  * (Windows) Fix unnecessary rebuilds caused by rebuilding
    winmanifest (#1933)
  * (Cygwin) Fix finding the Python library for Cygwin 64-bit (#1307,
    [#1810], #1811)
  * (OSX) Fix compilation issue (#1882)
  * (Windows) No longer bundle pefile, use package from for windows
    (#1357)
  * (Windows) Provide a more robust means of executing a Python script
  * AIX fixes.
  * Update waf to version 1.8.20 (#1868)
  * Fix excludedimports, more predictable order how hooks are applied
    [#1651]
  * Internal impovements and code clean-up (#1754, #1760, #1794,
    [#1858], #1862, #1887, #1907, #1913)
  * Clean-ups fixes and improvements for the test suite
  * Known Issues
    + Apps built with Windows 10 and Python 3.5 may not run on Windows
    versions earlier than 10 (#1566).
    + The multipackage (MERGE) feature (#1527) is currently broken.
    + (OSX) Support for OpenDocument events (#1309) is broken.
- updated to version 3.1.1:
  * Fix problems with setuptools 19.4 (#1772, #1773, #1790, #1791)
  * 3.1 does not collect certain direct imports (#1780)
  * Git reports wrong version even if on unchanged release (#1778)
  * Don’t resolve symlinks in modulegraph.py (#1750, #1755)
  * ShortFileName not returned in win32 util (#1799)
* Sat Jan 16 2016 termim@gmail.com
- Initial check in v3.1
